@@ -20,8 +20,10 @@ KEYS_ORDER: Tuple[Tuple[str, Tuple[str, ...]], ...] = (
         'metadata', (
             'name', 'version', 'description',
             'long_description', 'long_description_content_type',
-            'url', 'author', 'author_email', 'license', 'license_file',
-            'license_files', 'platforms', 'classifiers',
+            'url',
+            'author', 'author_email', 'maintainer', 'maintainer_email',
+            'license', 'license_file', 'license_files',
+            'platforms', 'classifiers',
         ),
     ),
     (
@@ -224,8 +226,8 @@ def _normalize_req(req: str) -> str:
     return f'{normalized};{envs}'
 
 
-BASE_NAME_REGEX = re.compile(r'[^!=><\s]+')
-REQ_REGEX = re.compile(r'(===|==|!=|~=|>=?|<=?)\s*([^,]+)')
+BASE_NAME_REGEX = re.compile(r'[^!=><\s@]+')
+REQ_REGEX = re.compile(r'(===|==|!=|~=|>=?|<=?|@)\s*([^,]+)')
 
 
 def _normalize_lib(lib: str) -> str:
@@ -306,8 +308,7 @@ def _trim_py_classifiers(
         size = len(ver)
         return (
             ver not in exclude and
-            # https://github.com/python/mypy/issues/7056
-            minimum[:size] <= ver <= max_py_version[:size]  # type: ignore
+            minimum[:size] <= ver <= max_py_version[:size]
         )
 
     return [s for s in classifiers if _is_ok_classifier(s)]
